@@ -15,7 +15,7 @@
 speMCA_varsup <- function(mca, df) {
     if (!is.data.frame(df)) stop("df must be a data frame")
     res <- lapply(names(df), function(name) {
-        l <- GDAtools::varsup(mca, df[, name])
+        l <- GDAtools::supvar(mca, df[, name])
         l <- lapply(l, function(x) {
             if (is.data.frame(x)) {
                 rownames(x) <- paste(name, rownames(x), sep = "____")
@@ -24,7 +24,7 @@ speMCA_varsup <- function(mca, df) {
         })
         l
     })
-    Reduce(function(acc, cur) {
+    res <- Reduce(function(acc, cur) {
         for (name in names(acc)) {
             if (name == "weight") next
             acc[[name]] <- dplyr::bind_rows(
@@ -34,4 +34,8 @@ speMCA_varsup <- function(mca, df) {
         }
         acc
     }, res)
-}
+
+    res$tab <- df
+
+    res
+}
\ No newline at end of file
